#
# spec file for package yelp-tools
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           yelp-tools
Version:        42.1
Release:        2.2
Summary:        Collection of utilities to help create documentation
License:        GPL-2.0-or-later
Group:          Development/Tools/Other
URL:            https://projects.gnome.org/yelp/
Source:         https://download.gnome.org/sources/yelp-tools/42/%{name}-%{version}.tar.xz
BuildRequires:  itstool
BuildRequires:  libxml2-tools
BuildRequires:  libxslt
BuildRequires:  meson >= 0.51.0
BuildRequires:  pkgconfig
BuildRequires:  python3-lxml
BuildRequires:  pkgconfig(yelp-xsl) >= 3.38.0
Requires:       itstool
Requires:       libxml2-tools
Requires:       libxslt
BuildArch:      noarch

%description
yelp-tools is a collection of scripts and build utilities to help create,
manage, and publish documentation for Yelp and the web. Most of the heavy
lifting is done by packages like yelp-xsl and itstool. This package just
wraps things up in a developer-friendly way.

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%python3_fix_shebang

%files
%license COPYING
%doc AUTHORS NEWS README.md
%{_bindir}/yelp-build
%{_bindir}/yelp-check
%{_bindir}/yelp-new
%dir %{_datadir}/aclocal
%{_datadir}/aclocal/yelp.m4
%{_datadir}/yelp-tools/

%changelog
* Thu Feb 22 2024 pgajdos@suse.com
- %%python3_fix_shebang do not need to be %%ifdef'ed
* Thu Feb 22 2024 pgajdos@suse.com
- remove dependency on /usr/bin/python3 using
  %%python3_fix_shebang macro, [bsc#1212476]
* Mon Oct 31 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.1:
  + Fixed issue with DocBook when path is missing trailing slash.
* Sun Mar 20 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.0:
  + No changes since beta, stable release only.
* Sat Feb 12 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.beta:
  + yelp.m4: Avoid argument list too long error when cleaning.
* Sun Sep 19 2021 Michael Gorse <mgorse@suse.com>
- Update to version 41.0:
  + Updates documentation.
  + Updates to build files.
* Mon Aug 23 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 41.beta:
  + Updates documentation.
* Sat Mar 20 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.0:
  + No changes since version 40.rc.
* Thu Mar 18 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.rc:
  + Added --skip option to skip files in yelp-check.
  + Custom checkers in yelp-check return 1 on failure.
- Drop 6.patch: merged upstream,
* Tue Feb 16 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add 6.patch: Use /usr/bin/python3 as shebang.
* Mon Feb 15 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 40.beta:
  + Added --skip option to skip files in yelp-check.
  + Custom checkers in yelp-check return 1 on failure.
* Tue Feb  9 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.alpha:
  + First release using the meson build system
  + Converted yelp-build, yelp-check, and yelp-new to python
  + New and improved templates for yelp-new
  + Support for .yelp-tools.cfg config file
  + Config file can specify custom checkers, like Schematron but easier
  + yelp-check hrefs takes a configurable allow list
- Switch to meson build system:
  + Add meson and python3-lxml BuildRequires.
  + Replace configure/make/make_install with respective
    meson/meson_build/meson_install.
* Mon Sep 14 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + Stable release. No changes since 3.37.90.
* Fri Sep  4 2020 dimstar@opensuse.org
- Update to version 3.37.90:
  + yelp-new: Added new templates.
* Thu Jun 13 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.2:
  + yelp-build: Fix spurious warning about missing stack files.
* Wed May  8 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.1:
  + yelp-check: Fix validation for DocBook 5 with https redirects.
* Mon Mar 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Stable release version bump.
* Thu Feb 14 2019 bjorn.lie@gmail.com
- Update to version 3.31.90:
  + Initial support for Mallard 1.2 stack files.
* Mon Mar 12 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + Stable release. No changes since 3.27.90.
* Mon Feb 26 2018 dimstar@opensuse.org
- Use SPDX3.0 license tags and package COPYING as %%license
* Tue Feb  6 2018 dimstar@opensuse.org
- Update to version 3.27.90:
  + Adapt to recent major changes in yelp-xsl.
  + yelp.m4: Disable net access in make check.
  + yelp-check:
  - Add --jing option to validate command to use jing.
  - Add style command to list page styles.
  - Remember URLs we already checked in `hrefs`.
* Fri Apr 15 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Mon Sep 21 2015 zaitor@opensuse.org
- Update to version 3.18.0:
  + Stable release. No changes since 3.17.4.
* Tue Jul 21 2015 zaitor@opensuse.org
- Update to version 3.17.4:
  + yelp-check: Sites support for orphans, links, media, status.
* Wed Jul  1 2015 dimstar@opensuse.org
- Update to version 3.17.3:
  + yelp-build:
  - Fix some broken and non-portable expr usage (bgo#743911).
  - Fixed media copying with -i for Mallard.
  - Added support for Mallard Sites to cache generator.
  + yelp-check:
  - Sites support for ids, hrefs, validate, comments, license.
  - Accept -h as well as --help.
* Tue Apr 14 2015 zaitor@opensuse.org
- Update to version 3.16.1:
  + yelp-check: Check media correctly in subdirs (bgo #727557).
* Mon Oct 13 2014 dimstar@opensuse.org
- Update to version 3.14.1:
  + yelp.m4: Fixed issues with make distcheck and install not
    running correclty unless make is run first (bgo#701959 and
    bgo#738142).
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Stable release. No changes since 3.13.3.
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 3.13.3:
  + Added support for .page.stub files in yelp-check.
* Wed Apr 16 2014 dimstar@opensuse.org
- Update to version 3.12.1:
  + yelp-check: Return non-zero exit status when there are broken
    hrefs.
* Tue Mar 25 2014 dimstar@opensuse.org
- Update to version 3.12.0:
  + Stable release. No changes since 3.11.5.
* Mon Feb  3 2014 dimstar@opensuse.org
- Update to version 3.11.5:
  + yelp-build:
  - Added -i option to ignore missing media files.
  - Added -p option to provide path for external files.
  - Set LC_ALL instead of LANG for awk (bgo#709354).
  + yelp-check:
  - Added check for missing media files.
  - Added tool to check Mallard page licenses.
  + yelp.m4: Use AS_HELP_STRING instead of AC_HELP_STRING
    (bgo#709657).
* Mon Dec 16 2013 dimstar@opensuse.org
- Update to version 3.11.3:
  + yelp.m4: no-lc-dist option to disable disting the generated lc
    files.
* Wed Nov 20 2013 dimstar@opensuse.org
- Update to version 3.11.2:
  + yelp.m4:
  - Added no-lc-media-links option for YELP_HELP_INIT.
  - Reverted HELP_MEDIA_NODUP and YELP_INIT_HELP.
* Mon Nov 18 2013 dimstar@opensuse.org
- Update to version 3.11.1:
  + yelp-build: Handle conditional processing and other logic when
    copying media and other external files (bgo#709951).
  + yelp=check:
  - Support validate on DocBook 5 documents.
  - Support explicitly allowed namespaces in strict validation.
  - Fixed POSIX shell syntax error (bgo#710331).
  + yelp-new: Now much smarter about output file paths and
    extensions.
  + yelp.m4:
  - Added HELP_MEDIA_NODUP to install media without locale
    symlinks.
  - Added YELP_INIT_HELP as version-checking replacement for
    YELP_HELP_INIT.
* Mon Sep 23 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Stable release. No changes since 3.9.90.
* Tue Aug 20 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + yelp-build: Fix directionality issues for Mallard.
  + yelp-check: Allow xml: attributes when validating in strict
    mode.
* Tue Jul 30 2013 dimstar@opensuse.org
- Update to version 3.9.1:
  + Fixed BSD compatibility issue in calling mktemp.
  + Fixed 'make pot' when srcdir != builddir.
  + yelp-check validate: Validate cache files.
  + yelp-check ids: New command to check Mallard page IDs.
  + yelp-build epub: Fixed issue with directory for media.
* Mon Oct 15 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + yelp-check: Added 'links -i' to ignore xrefs with hrefs.
  + yelp-check: Fixed extra angle brack in 'comments'.
* Mon Sep 24 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Stable release - no changes compared to 3.5.92.
* Mon Sep 17 2012 zaitor@opensuse.org
- Update to version 3.5.92:
  + yelp-check: Updated usage for 'yelp-check status'.
  + yelp-build: Fixed 'yelp-build epub --help'.
* Tue Sep  4 2012 dimstar@opensuse.org
- Update to version 3.5.91:
  + yelp-check: Handle local files in hrefs (bgo#673746)
  + Fixed xmllint/xsltproc version checks.
* Tue Apr 17 2012 vuntz@opensuse.org
- Update to version 3.4.1:
  + yelp.m4: Fix dist when using the LINGUAS envar
* Mon Mar 26 2012 zaitor@opensuse.org
- Update to version 3.4.0:
  + yelp-check: links and hrefs commands now work for DocBook.
* Mon Mar 19 2012 zaitor@opensuse.org
- Update to version 3.3.4:
  + yelp-check: Added --strict option to validate.
* Sun Feb 26 2012 vuntz@opensuse.org
- Change libxml2 BuildRequires and Requires to libxml2-tools for
  xmllint, now that tools got split from libxml2 package.
* Thu Feb 23 2012 vuntz@opensuse.org
- Update to version 3.3.3:
  + yelp.m4:
  - Fixed install/uninstall targets with lots of files
  - Only call mkdir_p once per directory
  - Dist all linguas, regardless of LINGUAS
  + yelp-build: Call html.js.custom
- Remove xz BuildRequires now that it comes for free in the build
  system.
* Mon Jan 23 2012 vuntz@opensuse.org
- Update to version 3.3.2:
  + yelp.m4: Custom distdir target to work around "Argument list
    too long"
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Thu Dec 22 2011 vuntz@opensuse.org
- Own %%{_datadir}/aclocal to fix build without automake/autoconf.
* Mon Nov 21 2011 dimstar@opensuse.org
- Update to version 3.3.1:
  + yelp.m4: Use stamp files to reduce rebuilds.
  + yelp-check: Add hrefs command to test external links.
  + Bugs fixed: bgo#651252, bgo#659421.
* Mon Oct 17 2011 dimstar@opensuse.org
- Update to version 3.2.1:
  + yelp-check status: Accept commas as a delimiter for options.
* Tue Sep 27 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + No change, just a version bump.
* Wed Sep 21 2011 vuntz@opensuse.org
- Update to version 3.1.7:
  + Do not use $(DESTDIR) when linking figures
* Tue Sep  6 2011 vuntz@opensuse.org
- Update to version 3.1.6:
  + Speed up cache generation in yelp-build
  + Added HELP_POT variable to specify pot name
  + Fixed --pkgversion lookup in 'yelp-check status'
* Mon Sep  5 2011 vuntz@opensuse.org
- Initial package, version 3.1.5.
